<?php
/* Smarty version {Smarty::SMARTY_VERSION}, created on 2019-06-05 10:38:14
  from "ls:LSformview.tpl" */

/* @var Smarty_Internal_Template $_smarty_tpl */
if ($_smarty_tpl->_decodeProperties($_smarty_tpl, array (
  'version' => '3.1.31',
  'unifunc' => 'content_5cf79b96828115_91133114',
  'has_nocache_code' => false,
  'file_dependency' => 
  array (
    'f237a4591f3ed336d8fdb8a71822083d249608cd' => 
    array (
      0 => 'ls:LSformview.tpl',
      1 => 1553870226,
      2 => 'ls',
    ),
  ),
  'includes' => 
  array (
  ),
),false)) {
function content_5cf79b96828115_91133114 (Smarty_Internal_Template $_smarty_tpl) {
?>
<input type='hidden' name='LSform_objecttype' id='LSform_objecttype'  value='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSform_object']->value['type'], ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
'/>
<input type='hidden' name='LSform_objectdn' id='LSform_objectdn'  value='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSform_object']->value['dn'], ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
'/>
<?php if ($_smarty_tpl->tpl_vars['LSform_layout']->value) {?>
  <!-- Tabs - Start Title -->
  <ul class='LSform_layout'>
  <?php
$_from = $_smarty_tpl->smarty->ext->_foreach->init($_smarty_tpl, $_smarty_tpl->tpl_vars['LSform_layout']->value, 'tab', false, 'tab_key');
if ($_from !== null) {
foreach ($_from as $_smarty_tpl->tpl_vars['tab_key']->value => $_smarty_tpl->tpl_vars['tab']->value) {
?>
    <li class='LSform_layout' id='LSform_layout_btn_<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['tab_key']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
'><a href='#<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['tab_key']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
'><?php echo LStemplate_smarty_tr(array('msg'=>$_smarty_tpl->tpl_vars['tab']->value['label']),$_smarty_tpl);?>
</a></li>
  <?php
}
}
$_smarty_tpl->smarty->ext->_foreach->restore($_smarty_tpl, 1);
?>

  </ul>
  <!-- Tabs - End Title -->

  <!-- Tabs - Start Content -->
  <?php
$_from = $_smarty_tpl->smarty->ext->_foreach->init($_smarty_tpl, $_smarty_tpl->tpl_vars['LSform_layout']->value, 'tab', false, 'tab_key');
if ($_from !== null) {
foreach ($_from as $_smarty_tpl->tpl_vars['tab_key']->value => $_smarty_tpl->tpl_vars['tab']->value) {
?>
    <a name='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['tab_key']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
'></a>
    <h2 class='LSform_layout'><?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['tab']->value['label'], ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
</h2>
    <div class='LSform LSform_layout' id='LSform_layout_div_<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['tab_key']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
'>
    
      <?php if ($_smarty_tpl->tpl_vars['LSformElement_image']->value != '' && $_smarty_tpl->tpl_vars['tab']->value['img'] == 1) {?>
        <div class='LSformElement_image'>
          <a href='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSformElement_image']->value['img'], ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
' rel='rien ici' title='comment' class='mb'><img src='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSformElement_image']->value['img'], ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
' class='LSformElement_image LSsmoothbox' id='LSformElement_image_<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSformElement_image']->value['id'], ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
' /></a>
        </div>
      <?php }?>
      
      <dl class='LSform'>
        <?php $_smarty_tpl->_assignInScope('field', 'non');
?>
        <?php
$_from = $_smarty_tpl->smarty->ext->_foreach->init($_smarty_tpl, $_smarty_tpl->tpl_vars['tab']->value['args'], 'arg');
if ($_from !== null) {
foreach ($_from as $_smarty_tpl->tpl_vars['arg']->value) {
?>
          <?php if ($_smarty_tpl->tpl_vars['LSform_fields']->value[$_smarty_tpl->tpl_vars['arg']->value]) {?>
            <?php $_smarty_tpl->_assignInScope('field', 'oui');
?>
            <dt class='LSform'><?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSform_fields']->value[$_smarty_tpl->tpl_vars['arg']->value]['label'], ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');
if ($_smarty_tpl->tpl_vars['LSform_fields']->value[$_smarty_tpl->tpl_vars['arg']->value]['help_info_in_view'] && $_smarty_tpl->tpl_vars['LSform_fields']->value[$_smarty_tpl->tpl_vars['arg']->value]['help_info'] != '') {?> <img class='LStips' src="<?php echo LStemplate_smarty_img(array('name'=>'help'),$_smarty_tpl);?>
" alt='?' title='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSform_fields']->value[$_smarty_tpl->tpl_vars['arg']->value]['help_info'], ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
'/><?php }?></dt>
            <dd class='LSform'><?php echo $_smarty_tpl->tpl_vars['LSform_fields']->value[$_smarty_tpl->tpl_vars['arg']->value]['html'];?>
</dd>
          <?php }?>
        <?php
}
}
$_smarty_tpl->smarty->ext->_foreach->restore($_smarty_tpl, 1);
?>

        <?php if ($_smarty_tpl->tpl_vars['field']->value == 'non') {?>
          <dd class='LSform'><?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSform_layout_nofield_label']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
</dd>
        <?php }?>
      </dl>
      
    </div>
  <?php
}
}
$_smarty_tpl->smarty->ext->_foreach->restore($_smarty_tpl, 1);
?>
  
  <!-- Tabs - End Content -->
<?php } else { ?>

  <?php if ($_smarty_tpl->tpl_vars['LSformElement_image']->value != '') {?>
  <div class='LSformElement_image'>
    <a href='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSformElement_image']->value['img'], ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
' rel='rien ici' title='comment' class='mb'><img src='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSformElement_image']->value['img'], ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
' class='LSformElement_image LSsmoothbox' id='LSformElement_image_<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSformElement_image']->value['id'], ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
' /></a>
  </div>
  <?php }?>

  <div class='LSform'>
    <dl class='LSform'>
      <?php
$_from = $_smarty_tpl->smarty->ext->_foreach->init($_smarty_tpl, $_smarty_tpl->tpl_vars['LSform_fields']->value, 'field');
if ($_from !== null) {
foreach ($_from as $_smarty_tpl->tpl_vars['field']->value) {
?>
      <dt class='LSform'><?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['field']->value['label'], ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
</dt>
      <dd class='LSform'><?php echo $_smarty_tpl->tpl_vars['field']->value['html'];?>
</dd>
      <?php
}
}
$_smarty_tpl->smarty->ext->_foreach->restore($_smarty_tpl, 1);
?>

    </dl>
  </div>
   
<?php }
}
}
